@extends('cms::admin.layouts.app')

@section('content')
    <form action="{{$formRoute}}" class="card" method="post" enctype="multipart/form-data">
        @csrf
        @method($formMethod)

        @include('erp::components.save')

        <div class="card-body">

            @component('cms::components.input')
                @slot('key', 'product_name')
                @slot('placeholder', trans('erp::erp.product_name'))
                @slot('validate', 'required')
                @slot('value', old('product_name', $product->product_name?? null))
            @endcomponent
            @component('cms::components.input')
                @slot('key', 'sku')
                @slot('placeholder', trans('erp::erp.sku'))
                @slot('validate', 'required')
                @slot('value', old('sku', $product->sku?? null))
            @endcomponent
            @component('cms::components.input')
                @slot('key', 'price')
                @slot('placeholder', trans('erp::erp.price_per_unit'))
                @slot('validate', 'required')
                @slot('type', 'number')
                @slot('value', old('price', $product->price?? 0))
            @endcomponent
            @component('cms::components.input')
                @slot('key', 'special_price')
                @slot('placeholder', trans('erp::erp.special_price'))
                @slot('type', 'number')
                @slot('value', old('special_price', $product->special_price?? 0))
            @endcomponent
            @component('cms::components.select2')
                @slot('key', 'manufacture_id')
                @slot('placeholder', trans('erp::erp.manufacture'))
                @slot('value', old('manufacture_id', $product->manufacture_id?? 0))
                @slot('attributes', ['required'])
                @slot('validate', 'required')
                @slot('options', $manufactures)
            @endcomponent
            @component('cms::components.select2')
                @slot('key', 'manufacturer_country')
                @slot('placeholder', trans('erp::erp.manufacturer_country'))
                @slot('value', old('manufacturer_country', $product->manufacturer_country?? null))
                @slot('validate', 'required')
                @slot('options', Lang::get('erp::countries'))
            @endcomponent

            <div class="row">
                <div class="col-12 col-sm-6">

                    @component('cms::components.hidden')
                        @slot('key', 'can_preorder')
                        @slot('value', 0)
                    @endcomponent
                    @component('cms::components.single_checkbox')
                        @slot('key', 'can_preorder')
                        @slot('placeholder', trans('erp::erp.preorder_allowed'))
                        @slot('value', $product->can_preorder?? 0)
                    @endcomponent
                </div>
            </div>
            <div class="row">
                <div class="col-12 col-sm-6 col-md-3">
                    @component('cms::components.input')
                        @slot('key', 'product_weight')
                        @slot('placeholder', trans('erp::erp.product_weight'))
                        @slot('validate', 'required')
                        @slot('type', 'number')
                        @slot('value', old('product_name', $product->product_weight?? null))
                    @endcomponent
                </div>
                <div class="col-12 col-sm-6 col-md-3">
                    @component('cms::components.input')
                        @slot('key', 'product_width')
                        @slot('placeholder', trans('erp::erp.product_width'))
                        @slot('validate', 'required')
                        @slot('type', 'number')
                        @slot('value', old('product_name', $product->product_width?? null))
                    @endcomponent
                </div>
                <div class="col-12 col-sm-6 col-md-3">
                    @component('cms::components.input')
                        @slot('key', 'product_height')
                        @slot('placeholder', trans('erp::erp.product_height'))
                        @slot('validate', 'required')
                        @slot('type', 'number')
                        @slot('value', old('product_name', $product->product_height?? null))
                    @endcomponent
                </div>
                <div class="col-12 col-sm-6 col-md-3">
                    @component('cms::components.input')
                        @slot('key', 'product_length')
                        @slot('placeholder', trans('erp::erp.product_length'))
                        @slot('validate', 'required')
                        @slot('type', 'number')
                        @slot('value', old('product_name', $product->product_length?? null))
                    @endcomponent
                </div>
            </div>
            @component('erp::components.image')
                @slot('key', 'image')
                @slot('placeholder', trans('erp::erp.image'))
                @slot('validate', 'required')
                @slot('value', old('image', $product->image?? null))
            @endcomponent

                @if($product->image !== null)
                    <div class="row">
                        <div class="col-12 col-sm-6 col-md-4 col-lg-3">
                            <img
                                class="img-fluid"
                                src="{{Storage::disk('public')->url("products/$product->sku/$product->image")}}" alt="">
                        </div>
                    </div>
                @endif
        </div>
    </form>
@endsection
