<?php

namespace TDevAgency\Erp\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Cache;
use TDevAgency\NovaPoshtaSdk\Api\AddressGeneral;
use TDevAgency\NovaPoshtaSdk\Facades\NovaPoshta;

class OrderDelivery extends Model
{
    protected $fillable = [
        'order_id',
        'delivery_code',
        'delivery_name',
        'delivery_status',
        'track_number',
        'delivery_price',
        'total_qty',
        'delivery_data',
    ];

    public function getDeliveryDataAttribute($value)
    {
        if ($value === null) {
            return null;
        }

        $data = unserialize(base64_decode($value));

        if (isset($data['delivery_formatted'])) {
            return $data['delivery_formatted'];
        }

        if (!isset($data['city_ref'], $data['wire_house_ref'])) {
            return null;
        }

        return Cache::rememberForever('delivery_data_' . $data['city_ref'] . $data['wire_house_ref'], function () use ($data) {
            $deps = NovaPoshta::addressGeneralModel()
                ->getWarehouses(['SettlementRef' => $data['city_ref']], AddressGeneral::CATEGORY_BRANCH)->toArray();

            $key = array_search($data['wire_house_ref'], array_column($deps, 'Ref'));

            if (!$key) {
                return null;
            }
            return sprintf('%s, %s.', $deps[$key]['DescriptionRu'], $deps[$key]['CityDescriptionRu']);
        });
    }
}
