<?php

namespace TDevAgency\Erp\Providers;

use Illuminate\Support\ServiceProvider;
use TDevAgency\Cms\Models\BaseModels\AdminUserRole;
use TDevAgency\Cms\Traits\ServiceProviderHelper;
use TDevAgency\Erp\Commands\ClearOrders;
use TDevAgency\Erp\Commands\ControllerMakeCommand;
use TDevAgency\Erp\Commands\ModelMakeCommand;
use TDevAgency\Erp\Commands\PublicAssets;
use TDevAgency\Erp\Helpers\Image;
use TDevAgency\Erp\Observers\AdminUserRoleObserver;

class ErpServiceProvider extends ServiceProvider
{

    use ServiceProviderHelper;

    /**
     * @var string
     */
    private $translationsPath;

    /**
     * var string
     */

    private $viewsPath;
    /**
     * @var string
     */
    private $migrationsPath;
    /**
     * @var string
     */
    private $noEditableTranslationsPath;

    public function __construct($app)
    {
        parent::__construct($app);

        $this->translationsPath = TDEV_AGENCY_ERP_ROOT . 'resources' . DIRECTORY_SEPARATOR . 'lang';
        $this->viewsPath = TDEV_AGENCY_ERP_ROOT . 'resources' . DIRECTORY_SEPARATOR . 'views';
        $this->migrationsPath = TDEV_AGENCY_ERP_ROOT . 'database' . DIRECTORY_SEPARATOR . 'migrations';
    }

    /**
     * Register services.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfigFrom(
            TDEV_AGENCY_ERP_ROOT . 'config' . DIRECTORY_SEPARATOR . 'cms_admin_sidebar.php', 'cms_admin_sidebar'
        );
        $this->mergeConfigFrom(
            TDEV_AGENCY_ERP_ROOT . 'config' . DIRECTORY_SEPARATOR . 'cms.php', 'cms'
        );
        $this->mergeConfigFrom(
            TDEV_AGENCY_ERP_ROOT . 'config' . DIRECTORY_SEPARATOR . 'erp.php', 'erp'
        );

    }

    /**
     * Bootstrap services.
     *
     * @return void
     */
    public function boot()
    {

        AdminUserRole::observe(AdminUserRoleObserver::class);
        $this->loadMigrationsFrom($this->migrationsPath);
        $this->loadViewsFrom($this->viewsPath, 'erp');
        $this->loadTranslationsFrom($this->translationsPath, 'erp');

        $this->commands([
            ModelMakeCommand::class,
            ControllerMakeCommand::class,
            PublicAssets::class,
            ClearOrders::class,
        ]);

        $this->app->singleton('Erp\ImageHelper', function ($app) {
            return new Image();
        });
    }

}
